@@ -40,7 +40,10 @@
 #' there are no variables specified in \code{match.covar.min} and
 #' \code{match.out.min}, the function \code{calibrate()} from the \code{survey}
 #' package is used to calculate weights.  Otherwise, the function
-#' \code{LowRankQP()} from the package of the same name is used.  In the event
+#' \code{LowRankQP()} from the package of the same name is used, if it is
+#' available on the user's machine (it is now in the CRAN archive, so would need
+#' to be installed by other means). If the \code{LowRankQP} package is unavailable,
+#' it will use \code{ipop()} from the \code{kernlab} package.  In the event
 #' that the model specified by \code{match.covar} and \code{match.out} is not
 #' feasible (i.e., weights do not exist that exactly match treatment and
 #' synthetic control subject to the given constraints), a less restrictive
@@ -327,6 +330,9 @@
 #'   documentation for \code{detectCores} makes clear that it is not failsafe and
 #'   could return a spurious number of available cores.
 #'
+#' @param ret.stats if set to \code{TRUE}, returns four additional elements:
+#'   \code{stats}, \code{stats1}, \code{stats2} and \code{delta.out}.
+#'
 #' @details \code{microsynth} calculates weights using
 #'   \code{survey::calibrate()} from the \code{survey} package in circumstances
 #'   where a feasible solution exists for all constraints, whereas
@@ -393,10 +399,19 @@
 #'   \code{Plot.Stats$Difference[,,i+1]} contains the time series of treatment
 #'   minus control for the i^th permutation group.
 #'
-#'   Lastly, \code{info} documents some input parameters for display by
+#'   Next, \code{info} documents some input parameters for display by
 #'   \code{print()}. A summary of weighted matching variables and of results
 #'   can be viewed using \code{\link{summary}}
 #'
+#'   Lastly, if \code{ret.stats} is set to \code{TRUE}, four additional elements
+#'   are returned: \code{stats}, \code{stats1}, \code{stats2} and \code{delta.out}.
+#'   \code{stats} contains elements with the basic statistics that are the same as
+#'   the main microsynth output: outcomes in treatment, control and percentage change.
+#'   \code{stats1} are the estimates of \code{svyglm()} adjusted by their standard
+#'   errors. \code{stats2} is the percent change in the observed value from each
+#'   outcome from the hypothetical outcome absent intervention. \code{delta.out} is
+#'   a Taylor series linearization used to approximate the variance of the estimator.
+#'
 #' @references Abadie A, Diamond A, Hainmueller J (2010). Synthetic control
 #'   methods for comparative case studies: Estimating the effect of California's
 #'   tobacco control program.? \emph{Journal of the American Statistical
@@ -442,7 +457,7 @@
 #' # Perform matching and estimation, without permutations or jackknife
 #' # runtime: < 1 min
 #'
-#' \dontrun{
+#' \donttest{
 #' sea1 <- microsynth(seattledmi,
 #'                   idvar='ID', timevar='time', intvar='Intervention',
 #'                   start.pre=1, end.pre=12, end.post=16,
@@ -454,8 +469,9 @@
 #' # View results
 #' summary(sea1)
 #' plot_microsynth(sea1)
+#' }
 #'
-#'
+#' \dontrun{
 #' # Repeat matching and estimation, with permutations and jackknife
 #' # Set permutations and jack-knife to very few groups (2) for
 #' # quick demonstration only.
@@ -582,19 +598,16 @@
 #'
 #' @export
 
-microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, end.pre = NULL, 
-    end.post = NULL, match.out = TRUE, match.covar = TRUE, match.out.min = NULL, match.covar.min = NULL, 
-    result.var = TRUE, omnibus.var = result.var, period = 1, scale.var = "Intercept", confidence = 0.9, 
-    test = "twosided", perm = 0, jack = 0, use.survey = TRUE, cut.mse = Inf, check.feas = FALSE, 
-    use.backup = FALSE, w = NULL, max.mse = 0.01, maxit = 250, cal.epsilon = 1e-04, calfun = "linear", 
-    bounds = c(0, Inf), result.file = NULL, printFlag = TRUE, n.cores = TRUE) {
-    
+microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, end.pre = NULL, end.post = NULL, match.out = TRUE, match.covar = TRUE, match.out.min = NULL, match.covar.min = NULL, result.var = TRUE,
+    omnibus.var = result.var, period = 1, scale.var = "Intercept", confidence = 0.9, test = "twosided", perm = 0, jack = 0, use.survey = TRUE, cut.mse = Inf, check.feas = FALSE, use.backup = FALSE, w = NULL, max.mse = 0.01,
+    maxit = 250, cal.epsilon = 1e-04, calfun = "linear", bounds = c(0, Inf), result.file = NULL, printFlag = TRUE, n.cores = TRUE, ret.stats = FALSE) {
+
     # Force to dataframe (e.g., not 'tibble')
     data <- as.data.frame(data)
-    
+
     # Determine the number of cores to be used. CRAN tops at 2.
     n.cores <- msCluster(n.cores)
-    
+
     # Declare metrics for print() call (1 of 3)
     info <- list()
     info$match <- unique(match.out)
@@ -604,7 +617,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
     info$start.pre <- start.pre
     info$end.pre <- end.pre
     info$end.post <- end.post
-    
+
     all.tmp <- proc.time()
     if (length(timevar) == 0) {
         if (length(table(data[, idvar])) < NROW(data)) {
@@ -618,12 +631,12 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
     time.tmp <- data[, timevar]
     time.names <- names(table(time.tmp))
     data[, timevar] <- match(as.character(time.tmp), time.names)
-    
+
     # Declare more metrics for print() call (2 of 3)
     info$nUnits <- length(unique(data[[idvar]]))  # num units
     info$nTreatment <- length(unique(data[idvar][data[intvar] == 1]))
     info$nControl <- info$nUnits - info$nTreatment
-    
+
     # Set up dummy variables for use in determining values of indirectly stated inputs
     if (length(start.pre) > 0 & !is.logical(start.pre)) {
         start.pre <- match(as.character(start.pre), time.names)
@@ -677,8 +690,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
     match.out <- remove.vars(match.out, dimnames(data)[[2]], "match.out", printFlag = printFlag)
     match.out.min <- remove.vars(match.out.min, dimnames(data)[[2]], "match.out.min", printFlag = printFlag)
     match.covar <- remove.vars(match.covar, dimnames(data)[[2]], "match.covar", printFlag = printFlag)
-    match.covar.min <- remove.vars(match.covar.min, dimnames(data)[[2]], "match.covar.min", 
-        printFlag = printFlag)
+    match.covar.min <- remove.vars(match.covar.min, dimnames(data)[[2]], "match.covar.min", printFlag = printFlag)
     result.var <- remove.vars(result.var, dimnames(data)[[2]], "out.covar", printFlag = printFlag)
     if (!is.logical(omnibus.var)) {
         omnibus.var <- remove.vars(omnibus.var, dimnames(data)[[2]], "omnibus.var", printFlag = printFlag)
@@ -711,10 +723,9 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
     data <- data[, !is.element(colnames(data), rm.col)]
     v.names <- setdiff(v.names, rm.col)
     nv.names <- setdiff(nv.names, rm.col)
-    
+
     # Shape panel data into 3D array, generate intervention matrix, etc.
-    data <- newreshape(data, nv.names = nv.names, v.names = v.names, timevar = timevar, 
-        idvar = idvar, intvar = intvar)
+    data <- newreshape(data, nv.names = nv.names, v.names = v.names, timevar = timevar, idvar = idvar, intvar = intvar)
     if (length(result.var) == 0) {
         result.var <- data[[4]]
         if (!reset.result.var) {
@@ -722,8 +733,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                 message("result.var = TRUE.  Resetting: \n", appendLF = FALSE)
             }
             if (printFlag) {
-                message("result.var = c(\"", paste(result.var, collapse = "\",\"", sep = ""), 
-                  "\")\n\n", sep = "", appendLF = FALSE)
+                message("result.var = c(\"", paste(result.var, collapse = "\",\"", sep = ""), "\")\n\n", sep = "", appendLF = FALSE)
             }
         }
     }
@@ -734,8 +744,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                 message("match.covar = TRUE.  Resetting: \n", appendLF = FALSE)
             }
             if (printFlag) {
-                message("match.covar = c(\"", paste(match.covar, collapse = "\",\"", sep = ""), 
-                  "\")\n\n", sep = "", appendLF = FALSE)
+                message("match.covar = c(\"", paste(match.covar, collapse = "\",\"", sep = ""), "\")\n\n", sep = "", appendLF = FALSE)
             }
         }
     }
@@ -770,8 +779,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                 message("match.out = TRUE.  Resetting: \n", appendLF = FALSE)
             }
             if (printFlag) {
-                message("match.out = c(\"", paste(match.out, collapse = "\",\"", sep = ""), 
-                  "\")\n\n", sep = "", appendLF = FALSE)
+                message("match.out = c(\"", paste(match.out, collapse = "\",\"", sep = ""), "\")\n\n", sep = "", appendLF = FALSE)
             }
         }
     }
@@ -786,8 +794,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
         match.out <- check.matchout(match.out, end.pre - min(times) + 1)
         if (match.out[[2]]) {
             if (printFlag) {
-                message("WARNING: match.out calls on time periods that are beyond the data range.\n", 
-                  sep = "", appendLF = FALSE)
+                message("WARNING: match.out calls on time periods that are beyond the data range.\n", sep = "", appendLF = FALSE)
             }
             if (printFlag) {
                 message("match.out is being reset accordingly.\n\n", sep = "", appendLF = FALSE)
@@ -806,8 +813,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
         match.out.min <- check.matchout(match.out.min, end.pre - min(times) + 1)
         if (match.out.min[[2]]) {
             if (printFlag) {
-                message("WARNING: match.out.min calls on time periods that are beyond the data range. \n", 
-                  sep = "", appendLF = FALSE)
+                message("WARNING: match.out.min calls on time periods that are beyond the data range. \n", sep = "", appendLF = FALSE)
             }
             if (printFlag) {
                 message("match.out.min is being reset accordingly.\n\n", sep = "", appendLF = FALSE)
@@ -825,8 +831,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                   message("omnibus.var = TRUE.  Resetting: \n", appendLF = FALSE)
                 }
                 if (printFlag) {
-                  message("omnibus.var = c(\"", paste(omnibus.var, collapse = "\",\"", sep = ""), 
-                    "\")\n\n", sep = "", appendLF = FALSE)
+                  message("omnibus.var = c(\"", paste(omnibus.var, collapse = "\",\"", sep = ""), "\")\n\n", sep = "", appendLF = FALSE)
                 }
             }
         } else {
@@ -846,8 +851,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
     dum1 <- ((max(end.post) - (max(end.post) - end.pre)%%period - end.pre)/period)
     if (dum <= dum1 + 1) {
         if (printFlag) {
-            message("WARNING: There is a low number (", dum, ") of cases in the treatment or intervention group.\n", 
-                sep = "", appendLF = FALSE)
+            message("WARNING: There is a low number (", dum, ") of cases in the treatment or intervention group.\n", sep = "", appendLF = FALSE)
         }
         if (jack > 0) {
             jack <- 0
@@ -862,8 +866,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
             }
         }
         if (printFlag) {
-            message("Be cautious of results involving linearization or confidence intervals.\n\n", 
-                appendLF = FALSE)
+            message("Be cautious of results involving linearization or confidence intervals.\n\n", appendLF = FALSE)
         }
     }
     if (reset.match.covar) {
@@ -876,78 +879,67 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
         for (i in 1:length(rm.col)) {
             if (is.element(rm.col[i], result.var)) {
                 if (printFlag) {
-                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from result.var. \n", 
-                    sep = "", appendLF = FALSE)
+                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from result.var. \n", sep = "", appendLF = FALSE)
                 }
                 result.var <- setdiff(result.var, rm.col[i])
             }
             if (is.element(rm.col[i], omnibus.var)) {
                 if (printFlag) {
-                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from omnibus.var. \n", 
-                    sep = "", appendLF = FALSE)
+                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from omnibus.var. \n", sep = "", appendLF = FALSE)
                 }
                 omnibus.var <- setdiff(omnibus.var, rm.col[i])
             }
             if (is.element(rm.col[i], match.covar)) {
                 if (printFlag) {
-                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from match.covar. \n", 
-                    sep = "", appendLF = FALSE)
+                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from match.covar. \n", sep = "", appendLF = FALSE)
                 }
                 match.covar <- setdiff(match.covar, rm.col[i])
             }
             if (is.element(rm.col[i], match.covar.min)) {
                 if (printFlag) {
-                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from match.covar.min. \n", 
-                    sep = "", appendLF = FALSE)
+                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from match.covar.min. \n", sep = "", appendLF = FALSE)
                 }
                 match.covar.min <- setdiff(match.covar.min, rm.col[i])
             }
             if (is.element(rm.col[i], names(match.out))) {
                 if (printFlag) {
-                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from match.out. \n", 
-                    sep = "", appendLF = FALSE)
+                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from match.out. \n", sep = "", appendLF = FALSE)
                 }
                 rm.li <- which(is.element(names(match.out), rm.col[i]))
                 match.out <- match.out[-rm.li]
             }
             if (is.element(rm.col[i], names(match.out.min))) {
                 if (printFlag) {
-                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from match.out.min. \n", 
-                    sep = "", appendLF = FALSE)
+                  message("WARNING: ", rm.col[i], " is a non-numeric variable.  It will be removed from match.out.min. \n", sep = "", appendLF = FALSE)
                 }
                 rm.li1 <- which(is.element(names(match.out.min), rm.col[i]))
                 match.out.min <- match.out.min[-rm.li1]
             }
         }
     }
-    
+
     # Establish synthetic control weights
     if (length(w) == 0) {
         tmp <- proc.time()
         if (printFlag) {
             message("Calculating weights...", "\n", appendLF = FALSE)
         }
-        w <- get.w(data, match.covar, match.covar.min, match.out, match.out.min, boot = perm, 
-            jack = jack, Int = Intervention[, as.character(end.pre)], int.val = int.num, 
-            trim = NULL, end.pre = end.pre, cal.epsilon = cal.epsilon, maxit = maxit, bounds = bounds, 
-            calfun = calfun, check.feas = check.feas, scale.var = scale.var, cut.mse = max.mse, 
-            use.backup = use.backup, time.names = time.names, printFlag = printFlag, n.cores = n.cores)
+        w <- get.w(data, match.covar, match.covar.min, match.out, match.out.min, boot = perm, jack = jack, Int = Intervention[, as.character(end.pre)], int.val = int.num, trim = NULL, end.pre = end.pre, cal.epsilon = cal.epsilon,
+            maxit = maxit, bounds = bounds, calfun = calfun, check.feas = check.feas, scale.var = scale.var, cut.mse = max.mse, use.backup = use.backup, time.names = time.names, printFlag = printFlag, n.cores = n.cores)
         tmp <- proc.time() - tmp
         if (printFlag) {
-            message("Calculation of weights complete: Total time = ", round(tmp[3], 2), 
-                "\n\n", sep = "", appendLF = FALSE)
+            message("Calculation of weights complete: Total time = ", round(tmp[3], 2), "\n\n", sep = "", appendLF = FALSE)
         }
     } else {
         if (printFlag) {
             message("Weights have been provided.  Will not calculate weights.\n", appendLF = FALSE)
         }
-        if (class(w) == "microsynth") {
+        if (methods::is(w) == "microsynth") {
             w <- w$w
         }
         is.correct.w <- is.list(w)
         if (is.correct.w) {
-            is.correct.w <- is.correct.w & sum(names(w) != c("Weights", "Intervention", 
-                "MSE", "Model", "Summary", "keep.groups")) == 0
+            is.correct.w <- is.correct.w & sum(names(w) != c("Weights", "Intervention", "MSE", "Model", "Summary", "keep.groups")) == 0
         }
         if (is.correct.w) {
             is.correct.w <- is.correct.w & dim(w$Weights)[1] == dim(data)[1]
@@ -982,22 +974,19 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
             is.graph <- "Calculating basic statistics"
             is.graph1 <- "Completed calculation of basic statistics"
             if (printFlag) {
-                message(is.graph, " for end.post = ", time.names[end.post[i]], "...", "\n", 
-                  sep = "", appendLF = FALSE)
+                message(is.graph, " for end.post = ", time.names[end.post[i]], "...", "\n", sep = "", appendLF = FALSE)
             }
-            
+
             # Calculate basic statistics
-            stats[[i]] <- get.stats(data, w$Weights, w$Intervention, w$keep.groups, result.var, 
-                end.pre = end.pre, period = period, end.post = end.post[i], omnibus.var = omnibus.var, 
-                start.pre = start.pre, cut.mse = cut.mse, twosided = twosided, time.names = time.names)
+            stats[[i]] <- get.stats(data, w$Weights, w$Intervention, w$keep.groups, result.var, end.pre = end.pre, period = period, end.post = end.post[i], omnibus.var = omnibus.var, start.pre = start.pre, cut.mse = cut.mse,
+                twosided = twosided, time.names = time.names)
             if (i == which.max(end.post)) {
                 plot.stats <- stats[[i]][[5]]
             }
             stats[[i]] <- stats[[i]][-5]
             tmp <- proc.time() - tmp
             if (printFlag) {
-                message(is.graph1, " for end.post = ", time.names[end.post[i]], ".  Time = ", 
-                  round(tmp[3], 2), "\n\n", sep = "", appendLF = FALSE)
+                message(is.graph1, " for end.post = ", time.names[end.post[i]], ".  Time = ", round(tmp[3], 2), "\n\n", sep = "", appendLF = FALSE)
             }
             if (!reset.result.var) {
                 w.tmp <- w$Weights
@@ -1011,14 +1000,12 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                 }
                 tmp <- proc.time()
                 if (printFlag) {
-                  message("Calculating survey statistics for end.post = ", time.names[end.post[i]], 
-                    "...", "\n", sep = "", appendLF = FALSE)
+                  message("Calculating survey statistics for end.post = ", time.names[end.post[i]], "...", "\n", sep = "", appendLF = FALSE)
                 }
-                
+
                 # Calculate complex (i.e., survey) statistics
-                stats.tmp <- get.stats1(data, w.tmp, Inter.tmp, mse.tmp, result.var, end.pre = end.pre, 
-                  period = period, end.post = end.post[i], omnibus.var = omnibus.var, twosided = twosided, 
-                  printFlag = printFlag, n.cores = n.cores)
+                stats.tmp <- get.stats1(data, w.tmp, Inter.tmp, mse.tmp, result.var, end.pre = end.pre, period = period, end.post = end.post[i], omnibus.var = omnibus.var, twosided = twosided, printFlag = printFlag,
+                  n.cores = n.cores)
                 stats1[[i]] <- stats.tmp[[1]]
                 stats2[[i]] <- stats.tmp[[2]]
                 delta.out[[i]] <- stats.tmp[[3]]
@@ -1026,9 +1013,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                 out.coefs[[i]] <- stats.tmp[[5]]
                 tmp <- proc.time() - tmp
                 if (printFlag) {
-                  message("Completed calculation of survey statistics for end.post = ", 
-                    time.names[end.post[i]], ".  Time = ", round(tmp[3], 2), "\n\n", sep = "", 
-                    appendLF = FALSE)
+                  message("Completed calculation of survey statistics for end.post = ", time.names[end.post[i]], ".  Time = ", round(tmp[3], 2), "\n\n", sep = "", appendLF = FALSE)
                 }
                 Pct.Chng <- cbind(Pct.Chng = stats[[i]][[2]][1, ])
                 if (is.element("Omnibus", rownames(Pct.Chng))) {
@@ -1045,15 +1030,12 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                 } else if (test == "upper") {
                   Linear.pVal <- cbind(Linear.pVal = stats::pnorm(synth.stats1[1, ], lower.tail = FALSE))
                 } else {
-                  Linear.pVal <- cbind(Linear.pVal = 2 * stats::pnorm(abs(synth.stats1[1, 
-                    ]), lower.tail = FALSE))
+                  Linear.pVal <- cbind(Linear.pVal = 2 * stats::pnorm(abs(synth.stats1[1, ]), lower.tail = FALSE))
                   if (is.element("Omnibus", rownames(Linear.pVal))) {
-                    Linear.pVal["Omnibus", ] <- stats::pchisq(synth.stats1[1, "Omnibus"], 
-                      df = synth.dof, lower.tail = FALSE)
+                    Linear.pVal["Omnibus", ] <- stats::pchisq(synth.stats1[1, "Omnibus"], df = synth.dof, lower.tail = FALSE)
                   }
                 }
-                Linear.CI <- make.ci(synth.stats2[1, ], sqrt(synth.delta.out[1, ]), alpha = 1 - 
-                  confidence)
+                Linear.CI <- make.ci(synth.stats2[1, ], sqrt(synth.delta.out[1, ]), alpha = 1 - confidence)
                 colnames(Linear.CI) <- paste("Linear.", colnames(Linear.CI), sep = "")
                 Jack.pVal <- Jack.CI <- Perm.pVal <- Perm.CI <- NULL
                 if (jack > 0) {
@@ -1070,8 +1052,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                   } else {
                     Jack.pVal <- cbind(Jack.pVal = 2 * stats::pnorm(abs(jack.stats1), lower.tail = FALSE))
                     if (is.element("Omnibus", rownames(Jack.pVal))) {
-                      Jack.pVal["Omnibus", ] <- stats::pchisq(c(jack.stats1)["Omnibus"], 
-                        df = synth.dof, lower.tail = FALSE)
+                      Jack.pVal["Omnibus", ] <- stats::pchisq(c(jack.stats1)["Omnibus"], df = synth.dof, lower.tail = FALSE)
                     }
                   }
                   Jack.CI <- make.ci(jack.stats2, sqrt(jack.delta.out), alpha = 1 - confidence)
@@ -1086,8 +1067,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                   } else if (test == "upper") {
                     Perm.pVal <- cbind(Perm.pVal = 1 - c(perm.stats1))
                   } else {
-                    Perm.pVal <- cbind(Perm.pVal = 2 * apply(cbind(c(perm.stats1), 1 - c(perm.stats1)), 
-                      1, min))
+                    Perm.pVal <- cbind(Perm.pVal = 2 * apply(cbind(c(perm.stats1), 1 - c(perm.stats1)), 1, min))
                     if (is.element("Omnibus", rownames(Perm.pVal))) {
                       Perm.pVal["Omnibus", ] <- 1 - c(perm.stats1)["Omnibus"]
                     }
@@ -1103,15 +1083,13 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
                   } else if (test == "upper") {
                     Perm.pVal <- cbind(Perm.pVal = 1 - c(perm.stats[1, ]))
                   } else {
-                    Perm.pVal <- cbind(Perm.pVal = 2 * pmin(c(perm.stats[1, ]), 1 - c(perm.stats[1, 
-                      ])))
+                    Perm.pVal <- cbind(Perm.pVal = 2 * pmin(c(perm.stats[1, ]), 1 - c(perm.stats[1, ])))
                     if (is.element("Omnibus", rownames(Perm.pVal))) {
                       Perm.pVal["Omnibus", ] <- 1 - c(perm.stats[1, ])["Omnibus"]
                     }
                   }
                 }
-                results[[i]] <- cbind(Trt, Con, Pct.Chng, Linear.pVal, Linear.CI, Jack.pVal, 
-                  Jack.CI, Perm.pVal, Perm.CI)
+                results[[i]] <- cbind(Trt, Con, Pct.Chng, Linear.pVal, Linear.CI, Jack.pVal, Jack.CI, Perm.pVal, Perm.CI)
                 if (NROW(results[[i]]) == 1) {
                   rownames(results[[i]]) <- result.var[1]
                 }
@@ -1132,7 +1110,7 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
             message("Returning weights only.\n", appendLF = FALSE)
         }
     }
-    
+
     # Tabulate results for output.
     out <- list()
     i <- 1
@@ -1151,7 +1129,6 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
         names(out)[i] <- "Plot.Stats"
         i <- i + 1
     }
-    ret.stats <- FALSE
     if (ret.stats) {
         out[[i]] <- stats
         names(out)[i] <- "stats"
@@ -1166,18 +1143,17 @@ microsynth <- function(data, idvar, intvar, timevar = NULL, start.pre = NULL, en
     }
     all.tmp <- proc.time() - all.tmp
     if (printFlag) {
-        message("microsynth complete: Overall time = ", round(all.tmp[3], 2), "\n\n", sep = "", 
-            appendLF = FALSE)
+        message("microsynth complete: Overall time = ", round(all.tmp[3], 2), "\n\n", sep = "", appendLF = FALSE)
     }
-    
+
     # Declare final output for print (3 of 3)
     info$nConstraints <- nrow(out$w$Summary) - 1
     info$num.constr <- out$w$num.constr
     out$w$num.constr <- NULL
-    
+
     # Add descriptive stats to output for print() call
     out$info <- info
-    
+
     out <- makemicrosynth(out)
     return(out)
 }
@@ -1191,7 +1167,7 @@ get.pval <- function(stats, p = NCOL(stats[[1]]), k = length(stats), ret.na = FA
     out <- matrix(NA, k, p)
     colnames(out) <- nams
     rownames(out) <- paste("Stat", 1:k, sep = "")
-    
+
     dum <- list()
     for (i in 1:k) {
         synth <- stats[[i]][1, ]
@@ -1210,8 +1186,7 @@ get.pval <- function(stats, p = NCOL(stats[[1]]), k = length(stats), ret.na = FA
 
 
 
-# Sub-function of microsynth(); reshape data to make 3D array with other necessary
-# outputs
+# Sub-function of microsynth(); reshape data to make 3D array with other necessary outputs
 newreshape <- function(data, timevar, idvar, intvar, v.names = NULL, nv.names = NULL) {
     times = names(table(data[, timevar]))
     if (length(v.names) == 0) {
@@ -1222,40 +1197,36 @@ newreshape <- function(data, timevar, idvar, intvar, v.names = NULL, nv.names =
     keep.nams <- c(idvar, timevar, intvar, nv.names, v.names)
     keep.nams <- names(table(keep.nams))
     data <- data[, keep.nams]
-    
+
     if (length(times) > 1) {
-        newdat <- stats::reshape(data, timevar = timevar, idvar = idvar, v.names = v.names1, 
-            direction = "wide")
+        newdat <- stats::reshape(data, timevar = timevar, idvar = idvar, v.names = v.names1, direction = "wide")
     } else if (length(times) == 1) {
         newdat <- data[, colnames(data) != timevar]
         append.cols <- setdiff(colnames(newdat), c(idvar, nv.names))
         append.cols <- which(is.element(colnames(newdat), append.cols))
-        colnames(newdat)[append.cols] <- paste(colnames(newdat)[append.cols], ".", times, 
-            sep = "")
+        colnames(newdat)[append.cols] <- paste(colnames(newdat)[append.cols], ".", times, sep = "")
     }
     intcols <- substr(colnames(newdat), 1, nchar(intvar)) == intvar
-    intcols <- intcols & (substr(colnames(newdat), nchar(intvar) + 1, nchar(intvar) + 1) == 
-        "" | substr(colnames(newdat), nchar(intvar) + 1, nchar(intvar) + 1) == ".")
+    intcols <- intcols & (substr(colnames(newdat), nchar(intvar) + 1, nchar(intvar) + 1) == "" | substr(colnames(newdat), nchar(intvar) + 1, nchar(intvar) + 1) == ".")
     intcols <- colnames(newdat)[intcols]
     int <- newdat[, intcols, drop = FALSE]
     colnames(int) <- gsub(paste(intvar, ".", sep = ""), "", colnames(int))
     intcols1 <- as.numeric(colnames(int))
     int <- int[, order(intcols1, decreasing = FALSE), drop = FALSE]
     rownames(int) <- newdat[, idvar]
-    
+
     v.names <- setdiff(v.names, intvar)
     nv.names <- setdiff(nv.names, intvar)
-    
+
     newdat <- newdat[, setdiff(colnames(newdat), intcols)]
-    
+
     out <- array(NA, c(NROW(newdat), length(nv.names) + length(v.names), NCOL(int)))
     dimnames(out) <- list(newdat[, idvar], c(nv.names, v.names), colnames(int))
-    
+
     for (i in 1:dim(out)[2]) {
         nam.tmp <- dimnames(out)[[2]][i]
         here <- substr(colnames(newdat), 1, nchar(nam.tmp)) == nam.tmp
-        here <- here & (substr(colnames(newdat), nchar(nam.tmp) + 1, nchar(nam.tmp) + 1) == 
-            "." | substr(colnames(newdat), nchar(nam.tmp) + 1, nchar(nam.tmp) + 1) == "")
+        here <- here & (substr(colnames(newdat), nchar(nam.tmp) + 1, nchar(nam.tmp) + 1) == "." | substr(colnames(newdat), nchar(nam.tmp) + 1, nchar(nam.tmp) + 1) == "")
         tmp <- newdat[, here, drop = FALSE]
         if (sum(here, na.rm = TRUE) > 1) {
             colnames(tmp) <- gsub(paste(dimnames(out)[[2]][i], ".", sep = ""), "", colnames(tmp))
@@ -1264,7 +1235,7 @@ newreshape <- function(data, timevar, idvar, intvar, v.names = NULL, nv.names =
         }
         out[, i, ] <- as.matrix(tmp)
     }
-    
+
     nv.names <- NULL
     if (dim(out)[3] > 1) {
         for (i in 1:dim(out)[2]) {
@@ -1277,9 +1248,9 @@ newreshape <- function(data, timevar, idvar, intvar, v.names = NULL, nv.names =
     } else {
         nv.names <- dimnames(out)[[2]]
     }
-    
+
     v.names <- setdiff(dimnames(out)[[2]], nv.names)
-    
+
     return(list(bigdat = out, Intervention = int, nv.names = nv.names, v.names = v.names))
 }
 
@@ -1288,13 +1259,12 @@ newreshape <- function(data, timevar, idvar, intvar, v.names = NULL, nv.names =
 # Sub-function of microsynth(); create results file (e.g., as CSV or XLSX)
 out.results <- function(results, end.pre, end.post = names(results), file = NULL, printFlag = TRUE) {
     use.xlsx <- length(end.post) > 1
-    
+
     if (substr(file, nchar(file) - 3, nchar(file)) == ".csv") {
         file <- substr(file, 1, nchar(file) - 4)
         if (use.xlsx) {
             if (printFlag) {
-                message("WARNING: Cannot return .csv file since length(end.post) > 1.  Returning .xlsx file instead.\n", 
-                  sep = "", appendLF = FALSE)
+                message("WARNING: Cannot return .csv file since length(end.post) > 1.  Returning .xlsx file instead.\n", sep = "", appendLF = FALSE)
             }
         }
     } else if (substr(file, nchar(file) - 3, nchar(file)) == ".xls") {
@@ -1304,12 +1274,12 @@ out.results <- function(results, end.pre, end.post = names(results), file = NULL
         file <- substr(file, 1, nchar(file) - 5)
         use.xlsx <- TRUE
     }
-    
+
     if (use.xlsx) {
         xlsx.loaded <- is.element("xlsx", loadedNamespaces())
         file <- paste(file, ".xlsx", sep = "")
         if (!requireNamespace("xlsx", quietly = TRUE)) {
-            stop("The xlsx package is needed when saving output with multiple post-intervention times, or when the file name specifies a .xlsx extension. Please install xlsx, or if you'd like to write to .csv, only select a single post-intervention time and append the filename appropriately.", 
+            stop("The xlsx package is needed when saving output with multiple post-intervention times, or when the file name specifies a .xlsx extension. Please install xlsx, or if you'd like to write to .csv, only select a single post-intervention time and append the filename appropriately.",
                 call. = FALSE)
         }
         if (!xlsx.loaded) {
@@ -1320,17 +1290,16 @@ out.results <- function(results, end.pre, end.post = names(results), file = NULL
         cspValColumn <- xlsx::CellStyle(wb, dataFormat = xlsx::DataFormat("0.0000"))
         csOtherColumn <- xlsx::CellStyle(wb, dataFormat = xlsx::DataFormat("0.00"))
         csPercColumn <- xlsx::CellStyle(wb, dataFormat = xlsx::DataFormat("0.0%"))
-        
+
         for (i in 1:length(end.post)) {
             out <- results[[i]]
             keep <- rowMeans(is.na(out)) < 1
             out <- out[keep, , drop = FALSE]
-            
-            is.pct <- grepl("pct", tolower(colnames(out))) | grepl("lower", tolower(colnames(out))) | 
-                grepl("upper", tolower(colnames(out)))
+
+            is.pct <- grepl("pct", tolower(colnames(out))) | grepl("lower", tolower(colnames(out))) | grepl("upper", tolower(colnames(out)))
             is.pval <- grepl("pval", tolower(colnames(out)))
             is.oth <- !is.pct & !is.pval
-            
+
             pct.list <- rep(list(csPercColumn), sum(is.pct))
             names(pct.list) <- as.character(which(is.pct))
             pval.list <- rep(list(cspValColumn), sum(is.pval))
@@ -1345,29 +1314,28 @@ out.results <- function(results, end.pre, end.post = names(results), file = NULL
             }
             p <- NCOL(out)
             n <- NROW(out)
-            
+
             nam <- paste("Max time = ", end.post[i], sep = "")
             sheet <- xlsx::createSheet(wb, sheetName = nam)
             xlsx::setColumnWidth(sheet, colIndex = 1:(p + 1), colWidth = 13)
             xlsx::addDataFrame(out, sheet, colStyle = c(pct.list, pval.list, oth.list))
-            
+
             bord1 <- xlsx::Border(color = "black", position = "BOTTOM", pen = "BORDER_THIN")
-            cb <- xlsx::CellBlock(sheet, startRow = 1, startColumn = 1, noRows = (n + 1), 
-                noColumns = (p + 1), create = FALSE)
+            cb <- xlsx::CellBlock(sheet, startRow = 1, startColumn = 1, noRows = (n + 1), noColumns = (p + 1), create = FALSE)
             xlsx::CB.setBorder(cb, border = bord1, rowIndex = 1, colIndex = 1:(p + 1))
-            
+
             font <- xlsx::Font(wb, isBold = TRUE)
             xlsx::CB.setFont(cb, font = font, rowIndex = 1, colIndex = 2:(p + 1))
-            
+
         }
-        
+
         xlsx::saveWorkbook(wb, file = file)
         rm(wb)
     } else {
         file <- paste(file, ".csv", sep = "")
         utils::write.csv(results[[1]], file, na = "")
     }
-    
+
 }
 
 
@@ -1375,10 +1343,10 @@ out.results <- function(results, end.pre, end.post = names(results), file = NULL
 # Sub-function of microsynth(); calculate confidence intervals
 make.ci <- function(means, ses, alpha = 0.05) {
     z.score <- stats::qnorm(1 - alpha/2)
-    
+
     lower <- means - ses * z.score
     upper <- means + ses * z.score
-    
+
     out <- cbind(exp(lower) - 1, exp(upper) - 1)
     rownames(out) <- names(means)
     colnames(out) <- c("Lower", "Upper")
@@ -1391,13 +1359,13 @@ make.ci <- function(means, ses, alpha = 0.05) {
 make.ci2 <- function(stats, delta.out, alpha = 0.05) {
     means <- stats[1, ]
     sds <- sqrt(delta.out[1, ])
-    
+
     z.scores <- stats/sqrt(delta.out)
     quants <- apply(z.scores, 2, stats::quantile, probs = c(alpha/2, 1 - alpha/2), na.rm = TRUE)
-    
+
     lower <- means - sds * quants[2, ]
     upper <- means - sds * quants[1, ]
-    
+
     out <- cbind(exp(lower) - 1, exp(upper) - 1)
     rownames(out) <- colnames(stats)
     colnames(out) <- c("Lower", "Upper")
@@ -1408,9 +1376,9 @@ make.ci2 <- function(stats, delta.out, alpha = 0.05) {
 
 # Sub-function of microsynth(); allow parellalization
 msCluster <- function(n) {
-    
+
     requireNamespace("parallel", quietly = TRUE)
-    
+
     if (is.logical(n)) {
         if (n) {
             n1 <- parallel::detectCores()
@@ -1424,11 +1392,11 @@ msCluster <- function(n) {
     } else {
         n1 <- n
     }
-    
+
     # use 2 cores if CRAN, otherwise, use number detected
     chk <- Sys.getenv("_R_CHECK_LIMIT_CORES_", "")
     cores <- ifelse(chk == TRUE, 2, n1)
-    
+
     return(cores)
 }
 
@@ -1441,21 +1409,20 @@ remove.vars <- function(vars, nams, objnam = "result.var", printFlag = TRUE) {
     } else {
         vars1 <- vars
     }
-    
+
     rm.vars <- setdiff(vars1, nams)
-    
+
     if (length(rm.vars) > 0) {
         rm.here <- which(is.element(vars1, rm.vars))
         vars <- vars[-rm.here]
         if (printFlag) {
-            message("WARNING: The following variables will be removed from ", objnam, " since they are not in the dataset: \n", 
-                sep = "", appendLF = FALSE)
+            message("WARNING: The following variables will be removed from ", objnam, " since they are not in the dataset: \n", sep = "", appendLF = FALSE)
         }
         if (printFlag) {
             message(paste(rm.vars, collapse = ", ", sep = ""), "\n\n", sep = "", appendLF = FALSE)
         }
     }
-    
+
     return(vars)
 }
 
